library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

PACKAGE p4pack IS
	COMPONENT vga_sync
 		port(clk								: IN STD_LOGIC;			
			hsync,vsync 					: OUT STD_LOGIC;
			clk_out_9mhz 							: OUT STD_LOGIC;		
			red, green, blue 				: OUT STD_LOGIC_VECTOR(5 DOWNTO 0);		
			led_1,led_2 					: OUT STD_LOGIC;
			pixel_row, pixel_column	: OUT STD_LOGIC_VECTOR(9 DOWNTO 0));
	END COMPONENT;
END p4pack;

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

LIBRARY work;
USE work.p4pack.all;

entity main is
PORT(   
		clk					: IN STD_LOGIC;
		clk_out_9mhz 		: OUT STD_LOGIC;		
		hsync,vsync 		: OUT STD_LOGIC;		
		red, green, blue 	: OUT STD_LOGIC_VECTOR(5 DOWNTO 0);		
		led_1, led_2 		: OUT STD_LOGIC);
end main;

architecture Behavioral of main is

SIGNAL Vert_sync_in : STD_LOGIC;

-- Video Display Signals
SIGNAL red_data, green_data, blue_data : std_logic_vector(5 DOWNTO 0);
-- Signals for Video ROM Memory for Pixel Data
SIGNAL pixel_col, pixel_row		: std_logic_vector(9 DOWNTO 0);

signal clk_buf_9mhz	:	std_logic;

begin

				-- Generate VGA sync signals for display
   SYNC:  vga_sync
 		PORT MAP(clk => clk, 
				red => red_data, green => green_data, blue => blue_data,	
				hsync => hsync, vsync => vsync, clk_out_9mhz => clk_buf_9mhz,
				led_1 => led_1, led_2 => led_2,
			 	pixel_row => pixel_row, pixel_column => pixel_col);	 							

clk_out_9mhz <= clk_buf_9mhz;

process(clk_buf_9mhz)
begin
   if (clk_buf_9mhz'event and clk_buf_9mhz='1') then
		red 		<= 	red_data;
		green 	<= 	green_data;
		blue 		<= 	blue_data;		
   end if;
end process;
		
end Behavioral;